summaryrefslogtreecommitdiffstats
path: root/kchart/kchartPageLayout.cc
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-06-25 05:28:35 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-06-25 05:28:35 +0000
commitf008adb5a77e094eaf6abf3fc0f36958e66896a5 (patch)
tree8e9244c4d4957c36be81e15b566b4aa5ea26c982 /kchart/kchartPageLayout.cc
parent1210f27b660efb7b37ff43ec68763e85a403471f (diff)
downloadkoffice-f008adb5a77e094eaf6abf3fc0f36958e66896a5.tar.gz
koffice-f008adb5a77e094eaf6abf3fc0f36958e66896a5.zip
TQt4 port koffice
This should enable compilation under both Qt3 and Qt4; fixes for any missed components will be forthcoming git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/applications/koffice@1238284 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'kchart/kchartPageLayout.cc')
-rw-r--r--kchart/kchartPageLayout.cc54
1 files changed, 27 insertions, 27 deletions
diff --git a/kchart/kchartPageLayout.cc b/kchart/kchartPageLayout.cc
index a5a45e7e..b678da7e 100644
--- a/kchart/kchartPageLayout.cc
+++ b/kchart/kchartPageLayout.cc
@@ -21,70 +21,70 @@
#include "kchartPageLayout.moc"
#include "kchart_params.h"
#include <knumvalidator.h>
-#include <qlineedit.h>
-#include <qlayout.h>
+#include <tqlineedit.h>
+#include <tqlayout.h>
#include <klocale.h>
-#include <qlabel.h>
-#include <qgroupbox.h>
+#include <tqlabel.h>
+#include <tqgroupbox.h>
namespace KChart
{
-KChartPageLayout::KChartPageLayout( KChartParams* _params, QWidget* parent, const char* name )
- : KDialogBase( parent, name, TRUE,i18n("Page Layout"),KDialogBase::Ok | KDialogBase::Cancel | KDialogBase::User1 | KDialogBase::Apply , KDialogBase::Ok,true )
+KChartPageLayout::KChartPageLayout( KChartParams* _params, TQWidget* tqparent, const char* name )
+ : KDialogBase( tqparent, name, TRUE,i18n("Page Layout"),KDialogBase::Ok | KDialogBase::Cancel | KDialogBase::User1 | KDialogBase::Apply , KDialogBase::Ok,true )
{
params=_params;
#if 0
- QWidget *page = new QWidget( this );
+ TQWidget *page = new TQWidget( this );
#else
- QGroupBox* page = new QGroupBox( 2, Qt::Horizontal, i18n("Margins"),
+ TQGroupBox* page = new TQGroupBox( 2, Qt::Horizontal, i18n("Margins"),
this );
#endif
setMainWidget(page);
// FIXME: The following code is strange, since it is written to
// use a grid layout with a standard QWidget. However, with the
// QGroupBox, it looks better, and since it actually works, there
// is no immediate need for rewriting. In the sake of clarity, it
- // should be done though, and we should use the layout
+ // should be done though, and we should use the tqlayout
// capabilities of the groupbox instead..
setButtonText( KDialogBase::User1, i18n("&Reset") );
- QGridLayout *grid = new QGridLayout(page, 4, 2, KDialog::marginHint(), KDialog::spacingHint());
+ TQGridLayout *grid = new TQGridLayout(page, 4, 2, KDialog::marginHint(), KDialog::spacingHint());
- QLabel *lab=new QLabel(i18n("Left:"),page);
+ TQLabel *lab=new TQLabel(i18n("Left:"),page);
grid->addWidget(lab,0,0);
- leftBorder=new QLineEdit(page);
+ leftBorder=new TQLineEdit(page);
leftBorder->setValidator( new KIntValidator( 0,9999,leftBorder ) );
grid->addWidget(leftBorder,1,0);
- lab=new QLabel(i18n("Right:"),page);
+ lab=new TQLabel(i18n("Right:"),page);
grid->addWidget(lab,0,1);
- rightBorder=new QLineEdit(page);
+ rightBorder=new TQLineEdit(page);
rightBorder->setValidator( new KIntValidator( 0,9999,rightBorder ) );
grid->addWidget(rightBorder,1,1);
- lab=new QLabel(i18n("Top:"),page);
+ lab=new TQLabel(i18n("Top:"),page);
grid->addWidget(lab,2,0);
- topBorder=new QLineEdit(page);
+ topBorder=new TQLineEdit(page);
topBorder->setValidator( new KIntValidator( 0,9999,topBorder ) );
grid->addWidget(topBorder,3,0);
- lab=new QLabel(i18n("Bottom:"),page);
+ lab=new TQLabel(i18n("Bottom:"),page);
grid->addWidget(lab,2,1);
- bottomBorder=new QLineEdit(page);
+ bottomBorder=new TQLineEdit(page);
bottomBorder->setValidator( new KIntValidator( 0,9999,bottomBorder ) );
grid->addWidget(bottomBorder,3,1);
init();
- connect( this, SIGNAL( okClicked() ), this, SLOT( slotOk() ) );
- connect( this, SIGNAL( applyClicked() ), this, SLOT( slotApply() ) );
- connect( this, SIGNAL( user1Clicked() ), this ,SLOT( slotReset() ));
+ connect( this, TQT_SIGNAL( okClicked() ), this, TQT_SLOT( slotOk() ) );
+ connect( this, TQT_SIGNAL( applyClicked() ), this, TQT_SLOT( slotApply() ) );
+ connect( this, TQT_SIGNAL( user1Clicked() ), this ,TQT_SLOT( slotReset() ));
}
@@ -111,10 +111,10 @@ void KChartPageLayout::slotApply()
void KChartPageLayout::slotReset()
{
- rightBorder->setText(QString::number(oldGlobalLeadingRight));
- leftBorder->setText(QString::number(oldGlobalLeadingLeft));
- topBorder->setText(QString::number(oldGlobalLeadingTop));
- bottomBorder->setText(QString::number(oldGlobalLeadingBottom));
+ rightBorder->setText(TQString::number(oldGlobalLeadingRight));
+ leftBorder->setText(TQString::number(oldGlobalLeadingLeft));
+ topBorder->setText(TQString::number(oldGlobalLeadingTop));
+ bottomBorder->setText(TQString::number(oldGlobalLeadingBottom));
}
} //KChart namespace
@@ -21,70 +21,70 @@
setMainWidget(page);
// FIXME: The following code is strange, since it is written to
- // use a grid layout with a standard QWidget. However, with the
- // QGroupBox, it looks better, and since it actually works, there
+ // use a grid tqlayout with a standard TQWidget. However, with the
+ // TQGroupBox, it looks better, and since it actually works, there
// is no immediate need for rewriting. In the sake of clarity, it